%define lib_major        2
%define libname          %mklibname cairo %{lib_major}
%define libnamedev       %mklibname cairo -d
%define libnamestaticdev %mklibname cairo -s -d

#gw check coverage fails in 1.9.4
%define enable_test 0
%define stable 0
%define build_doc 1
%define build_gl 1

Summary:	Cairo - multi-platform 2D graphics library
Name:		cairo
Version:	1.16.0
Release:	%mkrel 6
License:	BSD
Group:		System/Libraries
URL:		https://www.cairographics.org/

%if %{stable}
Source0:	https://www.cairographics.org/releases/%{name}-%{version}.tar.xz
Source1:	https://www.cairographics.org/releases/%{name}-%{version}.tar.xz.sha1
%else
Source0:	https://www.cairographics.org/snapshots/%{name}-%{version}.tar.xz
Source1:	https://www.cairographics.org/snapshots/%{name}-%{version}.tar.xz.sha1
%endif

# Fedora patches:
#       >> None for now.
# upstream:
#       >> None for now.

# https://www.openwall.com/lists/oss-security/2018/12/07/3
# https://bugs.mageia.org/show_bug.cgi?id=23971
Patch1: https://gitlab.freedesktop.org/cairo/cairo/merge_requests/5.patch

# Security patches
Patch2: cairo-get_bitmap_surface-bsc1036789-CVE-2017-7475.diff
Patch3: cairo-1.16.0-CVE-2020-35492.patch 
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xrender)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(glib-2.0)
%if %{build_gl}
BuildRequires:	GL-devel
BuildRequires:	EGL-devel
%endif
BuildRequires:	pkgconfig(pixman-1)
BuildRequires:	pkgconfig(libpng)

%if %{enable_test}
# needed by tests
BuildRequires:	fonts-ttf-bitstream-vera
# only needed for pdf tests
#BuildRequires:	libpango-devel >= 1.13.0
# gw for svg tests
BuildRequires:	pkgconfig(librsvg-2.0)
# gw for ps testing
BuildRequires:	pkgconfig(libspectre)
# gw for pdf testing
BuildRequires:	pkgconfig(poppler-glib)
BuildRequires:	x11-server-xvfb
%endif

%if %build_doc
BuildRequires:	gtk-doc
%endif

%description
Cairo provides anti-aliased vector-based rendering for X. Paths
consist of line segments and cubic splines and can be rendered at any
width with various join and cap styles. All colors may be specified
with optional translucence (opacity/alpha) and combined using the
extended Porter/Duff compositing algebra as found in the X Render
Extension.

Cairo exports a stateful rendering API similar in spirit to the path
construction, text, and painting operators of PostScript, (with the
significant addition of translucence in the imaging model). When
complete, the API is intended to support the complete imaging model of
PDF 1.4.

Cairo relies on the Xc library for backend rendering. Xc provides an
abstract interface for rendering to multiple target types. As of this
writing, Xc allows Cairo to target X drawables as well as generic
image buffers. Future backends such as PostScript, PDF, and perhaps
OpenGL are currently being planned.

%package -n %{libname}
Summary:	Cairo - multi-platform 2D graphics library
Group:		System/Libraries
Provides:	cairo = %{version}-%{release}
Obsoletes:	%{_lib}cairo-xcb2 < 1.12.0

%description -n %{libname}
Cairo provides anti-aliased vector-based rendering for X. Paths
consist of line segments and cubic splines and can be rendered at any
width with various join and cap styles. All colors may be specified
with optional translucence (opacity/alpha) and combined using the
extended Porter/Duff compositing algebra as found in the X Render
Extension.

Cairo exports a stateful rendering API similar in spirit to the path
construction, text, and painting operators of PostScript, (with the
significant addition of translucence in the imaging model). When
complete, the API is intended to support the complete imaging model of
PDF 1.4.

Cairo relies on the Xc library for backend rendering. Xc provides an
abstract interface for rendering to multiple target types. As of this
writing, Xc allows Cairo to target X drawables as well as generic
image buffers. Future backends such as PostScript, PDF, and perhaps
OpenGL are currently being planned.

%package -n %{libnamedev}
Summary:	Development files for Cairo library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}cairo-xcb-devel < 1.12.0

%description -n %{libnamedev}
Development files for Cairo library.

%package -n %{libnamestaticdev}
Summary:	Static Cairo library
Group:		Development/C
Requires:	%{libnamedev} = %{version}-%{release}
Provides:	lib%{name}-static-devel = %{version}-%{release}
Obsoletes:	%{_lib}cairo-xcb-static-devel < 1.12.0

%description -n %{libnamestaticdev}
Static Cairo library.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -vfi
%configure \
%if %{build_doc}
	--enable-gtk-doc \
%endif
	--enable-pdf \
	--enable-ps \
	--enable-xcb \
	--enable-tee \
	--disable-directfb \
	--enable-freetype \
	--enable-xlib \
%if %{build_gl}
	--enable-gl \
%else
	--disable-gl \
%endif
	--enable-gobject
%make_build

%if %{enable_test}
%check
XDISPLAY=$(i=1; while [ -f /tmp/.X$i-lock ]; do i=$(($i+1)); done; echo $i)
%{_bindir}/Xvfb -screen 0 1600x1200x24 :$XDISPLAY &
export DISPLAY=:$XDISPLAY
make check
kill $(cat /tmp/.X$XDISPLAY-lock)
%endif

%install
%make_install

#we don't want these
find %{buildroot} -name "*.la" -delete

%files -n %{libname}
%doc AUTHORS COPYING NEWS README
%{_libdir}/libcairo.so.%{lib_major}{,.*}
%{_libdir}/libcairo-gobject.so.%{lib_major}{,.*}
%{_libdir}/libcairo-script-interpreter.so.%{lib_major}{,.*}

%files -n %{libnamedev}
%doc RELEASING BIBLIOGRAPHY BUGS ChangeLog
%doc %{_datadir}/gtk-doc/html/cairo/
%{_bindir}/cairo-trace
%{_bindir}/cairo-sphinx
%{_libdir}/cairo/
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%files -n %{libnamestaticdev}
%{_libdir}/lib*.a


%changelog
* Wed Jan 13 2021 neoclust <neoclust> 1.16.0-6.mga8
+ Revision: 1671601
- Add P3: Fixes CVE-2020-35492 (mga#28084)

* Sat Sep 26 2020 pterjan <pterjan> 1.16.0-5.mga8
+ Revision: 1630607
- Rebuild for libcairo2-1.16.0-4.mga8.armv7hl (due to unsatisfied libEGL.so.1)

* Wed Sep 02 2020 ns80 <ns80> 1.16.0-4.mga8
+ Revision: 1620931
- add OpenSuse patch for CVE-2017-7475 (mga#26981)
+ wally <wally>
- drop gcc 4.9 hacks
- drop plf build
+ danf <danf>
- Switch URLs from http: to https:

* Fri Feb 14 2020 umeabot <umeabot> 1.16.0-3.mga8
+ Revision: 1520770
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Dec 09 2018 shlomif <shlomif> 1.16.0-2.mga7
+ Revision: 1339121
- add patch to fix a crash when using freetype >= 2.9 (mga#23971)

* Mon Oct 22 2018 tv <tv> 1.16.0-1.mga7
+ Revision: 1323994
- new release

* Sat Sep 22 2018 umeabot <umeabot> 1.15.14-2.mga7
+ Revision: 1295836
- Mageia 7 Mass Rebuild

* Fri Sep 21 2018 daviddavid <daviddavid> 1.15.14-1.mga7
+ Revision: 1294645
- new version 1.15.14

* Fri Aug 03 2018 guillomovitch <guillomovitch> 1.15.12-1.mga7
+ Revision: 1247121
- new version 1.15.12

* Wed Mar 14 2018 tv <tv> 1.15.10-1.mga7
+ Revision: 1209471
- new release

* Thu Jun 22 2017 luigiwalser <luigiwalser> 1.14.10-1.mga6
+ Revision: 1108151
- 1.14.10

* Thu Apr 27 2017 neoclust <neoclust> 1.14.8-2.mga6
+ Revision: 1097790
- Add P1000 - Fixes CVE-2016-9082 (mga#19666)

* Mon Dec 12 2016 luigiwalser <luigiwalser> 1.14.8-1.mga6
+ Revision: 1074404
- 1.14.8

* Sun Nov 27 2016 wally <wally> 1.14.6-4.mga6
+ Revision: 1070425
- remove unneeded requires for freetype2

* Fri Aug 19 2016 blino <blino> 1.14.6-3.mga6
+ Revision: 1046978
- disable again directfb backend, it is not accelerated anymore and not worth pulling DirectFB by default on all systems

* Tue Jan 05 2016 blino <blino> 1.14.6-2.mga6
+ Revision: 919835
- enable back DirectFB backend

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.14.6-1.mga6
+ Revision: 918705
- 1.14.6

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.14.4-2.mga6
+ Revision: 918211
- rebuild without directfb

* Thu Nov 19 2015 ovitters <ovitters> 1.14.4-1.mga6
+ Revision: 904326
- new version 1.14.4

* Fri Jun 26 2015 shlomif <shlomif> 1.14.2-1.mga6
+ Revision: 844458
- New version 14.2

* Sun Feb 08 2015 tmb <tmb> 1.14.0-1.mga5
+ Revision: 814049
- pdf-operators: fix bug with RTL text
- xlib: Bump reference count for recording surface replays
- image: Fix crash in _fill_xrgb32_lerp_opaque_spans
+ shlomif <shlomif>
- New version 1.14.0

* Wed Oct 15 2014 umeabot <umeabot> 1.12.16-9.mga5
+ Revision: 748061
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 pterjan <pterjan> 1.12.16-8.mga5
+ Revision: 693379
- Rebuild to fix dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.12.16-7.mga5
+ Revision: 678283
- Mageia 5 Mass Rebuild

* Wed Aug 06 2014 sander85 <sander85> 1.12.16-6.mga5
+ Revision: 660232
- Rebuild for directfb

* Sat May 17 2014 shlomif <shlomif> 1.12.16-5.mga5
+ Revision: 623210
- Workaround for building with gcc-4.9.x.
  See https://bugs.archlinux.org/task/40313?project=1&openedfrom=-1+week .
+ tmb <tmb>
- rebuild for new directfb
+ wally <wally>
- add patch from Suse to avoid version number in module file names
- tag docs as such
- drop old and unneeded Mdv era obsoletes/conflicts

* Wed Apr 30 2014 ovitters <ovitters> 1.12.16-4.mga5
+ Revision: 618970
- rebuild for new directfb

* Sat Feb 15 2014 luigiwalser <luigiwalser> 1.12.16-3.mga5
+ Revision: 592117
- rebuild for directfb

* Sat Oct 19 2013 umeabot <umeabot> 1.12.16-2.mga4
+ Revision: 533229
- Mageia 4 Mass Rebuild

* Tue Aug 27 2013 tv <tv> 1.12.16-1.mga4
+ Revision: 472291
- new release

* Sat Aug 17 2013 fwang <fwang> 1.12.14-4.mga4
+ Revision: 467235
- rebuild for new dfb

* Mon Jun 10 2013 tv <tv> 1.12.14-3.mga4
+ Revision: 441771
- add fixes from FC

* Sun Jun 02 2013 fwang <fwang> 1.12.14-2.mga4
+ Revision: 434590
- rebuild for new libpng

* Sat May 25 2013 tv <tv> 1.12.14-1.mga4
+ Revision: 427124
- new release

* Thu Jan 31 2013 tv <tv> 1.12.12-1.mga3
+ Revision: 393821
- new release

* Fri Jan 11 2013 umeabot <umeabot> 1.12.8-2.mga3
+ Revision: 347302
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 05 2012 fwang <fwang> 1.12.8-1.mga3
+ Revision: 314288
- new version 1.12.8

* Fri Oct 05 2012 tv <tv> 1.12.4-1.mga3
+ Revision: 302969
- new release

* Thu Sep 27 2012 tv <tv> 1.12.2-4.mga3
+ Revision: 298609
- rebuild for new pango

* Sat Jul 28 2012 fwang <fwang> 1.12.2-3.mga3
+ Revision: 275237
- rebuild for new directfb

* Tue May 29 2012 fwang <fwang> 1.12.2-2.mga3
+ Revision: 249297
- obsolete old xcb flavour of cairo

* Tue May 29 2012 tv <tv> 1.12.2-1.mga3
+ Revision: 249140
- new release
- enable gl backend

* Sat Dec 17 2011 blino <blino> 1.10.2-6.mga2
+ Revision: 183177
- enable directfb surface (directfb is already pulled by SDL, which is required by cheese/ekiga/gimp/...)

* Sat Sep 10 2011 fwang <fwang> 1.10.2-5.mga2
+ Revision: 142079
- rebuild for new libpng

* Thu Jun 30 2011 fwang <fwang> 1.10.2-4.mga2
+ Revision: 116868
- cleanup pixman pkgname req
+ ahmad <ahmad>
- Drop patch4, already applied upstream since 1.9.10
+ rtp <rtp>
- put xvfb inside %%enable_test %%if as it's only used when testing

* Sat Jan 29 2011 dmorgan <dmorgan> 1.10.2-3.mga1
+ Revision: 43448
- enable tee backend feature for ff>=4.0b10
+ blino <blino>
- remove old macros
- imported package cairo


* Mon Dec 27 2010 Funda Wang <fwang@mandriva.org> 1.10.2-1mdv2011.0
+ Revision: 625367
- update to new version 1.10.2

* Mon Sep 06 2010 Götz Waschk <waschk@mandriva.org> 1.10.0-1mdv2011.0
+ Revision: 576391
- update build deps
- new stable version
- update file list

* Mon Jul 26 2010 Götz Waschk <waschk@mandriva.org> 1.9.14-1mdv2011.0
+ Revision: 560852
- update to new version 1.9.14

* Tue Jul 13 2010 Götz Waschk <waschk@mandriva.org> 1.9.12-1mdv2011.0
+ Revision: 551984
- update to new version 1.9.12

* Sat Jul 10 2010 Götz Waschk <waschk@mandriva.org> 1.9.10-1mdv2011.0
+ Revision: 550294
- update to new version 1.9.10
- new version
- drop patches 6-8
- fix source URL
- fix permissions of cairo-trace (bug #59550)

* Tue May 25 2010 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.9.6-3mdv2010.1
+ Revision: 545842
- Add git patch that fix ps creation
  CCBUG: 56979

* Thu Apr 15 2010 Frederic Crozat <fcrozat@mandriva.com> 1.9.6-2mdv2010.1
+ Revision: 535035
- Patch7 (GIT): do not touch cairo error object (GNOME bug #599574)

* Mon Feb 22 2010 Christophe Fergeau <cfergeau@mandriva.com> 1.9.6-1mdv2010.1
+ Revision: 509535
- cairo 1.9.6:
- drop 'fix-stroker-crash' patch which is already included in this release
- add patch to fix linking with pthread library

* Thu Jan 21 2010 Frederic Crozat <fcrozat@mandriva.com> 1.9.4-2mdv2010.1
+ Revision: 494634
- Patch6 (GIT): fix stroker crash (fdo #24797)

  + Götz Waschk <waschk@mandriva.org>
    - update build deps for checks

* Wed Dec 02 2009 Götz Waschk <waschk@mandriva.org> 1.9.4-1mdv2010.1
+ Revision: 472563
- new version
- update file list

* Thu Sep 24 2009 Olivier Blin <oblin@mandriva.com> 1.8.8-2mdv2010.0
+ Revision: 448206
- add a %%build_doc macro (from Arnaud Patard)
- put ttf font used for test in a test on %%enable_test (from Arnaud Patard)

* Tue Jun 16 2009 Götz Waschk <waschk@mandriva.org> 1.8.8-1mdv2010.0
+ Revision: 386468
- new version
- drop patch 0

* Tue Mar 24 2009 Götz Waschk <waschk@mandriva.org> 1.8.6-3mdv2009.1
+ Revision: 360803
- fix crash (bug #49067)

* Tue Feb 24 2009 Götz Waschk <waschk@mandriva.org> 1.8.6-2mdv2009.1
+ Revision: 344471
- add subpixel hinting patches (disabled by default)

* Wed Dec 17 2008 Frederic Crozat <fcrozat@mandriva.com> 1.8.6-1mdv2009.1
+ Revision: 315092
- Release 1.8.6

* Fri Nov 14 2008 Frederic Crozat <fcrozat@mandriva.com> 1.8.4-1mdv2009.1
+ Revision: 303287
- Release 1.8.4

* Fri Nov 07 2008 Olivier Blin <oblin@mandriva.com> 1.8.2-2mdv2009.1
+ Revision: 300396
- rebuild for new xcb

* Fri Oct 31 2008 Götz Waschk <waschk@mandriva.org> 1.8.2-1mdv2009.1
+ Revision: 298845
- update to new version 1.8.2

* Fri Sep 26 2008 Götz Waschk <waschk@mandriva.org> 1.8.0-1mdv2009.0
+ Revision: 288568
- update to new version 1.8.0

* Fri Sep 19 2008 Götz Waschk <waschk@mandriva.org> 1.7.6-1mdv2009.0
+ Revision: 285877
- new version

* Tue Aug 12 2008 Götz Waschk <waschk@mandriva.org> 1.7.4-1mdv2009.0
+ Revision: 271010
- new version
- bump pixman dep

* Thu Jul 24 2008 Frederic Crozat <fcrozat@mandriva.com> 1.6.4-2mdv2009.0
+ Revision: 245167
- Rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Apr 14 2008 Götz Waschk <waschk@mandriva.org> 1.6.4-1mdv2009.0
+ Revision: 192677
- new version
- drop patch

* Wed Apr 02 2008 Frederic Crozat <fcrozat@mandriva.com> 1.5.16-1mdv2008.1
+ Revision: 191616
- Release 1.5.16
- Patch0: various fixes from GIT

* Fri Mar 21 2008 Frederic Crozat <fcrozat@mandriva.com> 1.5.14-1mdv2008.1
+ Revision: 189348
- Release 1.5.14
- Remove patch0, merged upstream
- Patch0 (GIT): additional fixes for PDF and PS backends

* Thu Mar 20 2008 Frederic Crozat <fcrozat@mandriva.com> 1.5.12-2mdv2008.1
+ Revision: 189137
- Patch0 (GIT): fix type1 font being misaligned for PS generation

* Fri Feb 29 2008 Frederic Crozat <fcrozat@mandriva.com> 1.5.12-1mdv2008.1
+ Revision: 176685
- Release 1.5.12

* Wed Feb 20 2008 Frederic Crozat <fcrozat@mandriva.com> 1.5.10-1mdv2008.1
+ Revision: 173243
- Release 1.5.10

* Thu Jan 31 2008 Götz Waschk <waschk@mandriva.org> 1.5.8-1mdv2008.1
+ Revision: 160649
- new version
- update docs list

* Thu Jan 17 2008 Frederic Crozat <fcrozat@mandriva.com> 1.5.6-1mdv2008.1
+ Revision: 153966
- Release 1.5.6

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Dec 12 2007 Frederic Crozat <fcrozat@mandriva.com> 1.5.4-1mdv2008.1
+ Revision: 118260
- Fix buildrequires
- Release 1.5.4

  + Thierry Vignaud <tv@mandriva.org>
    - buildrequires X11-devel instead of XFree86-devel

* Wed Nov 28 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.12-1mdv2008.1
+ Revision: 113660
- Release 1.4.12
- Remove patches 0, 1, merged upstream

* Wed Oct 31 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.10-3mdv2008.1
+ Revision: 104227
- Patch1 (GIT): fix empty glyph handling (fd.o bug #12284). Fully fix PDF rendering in Evince

* Wed Oct 31 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.10-2mdv2008.1
+ Revision: 104209
- Patch0: fix handling of invalid glyph request (fd.o bugs #9846, #8399)

  + Götz Waschk <waschk@mandriva.org>
    - new devel name

* Wed Jul 04 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.10-1mdv2008.0
+ Revision: 48136
- Release 1.4.10

* Mon Jun 11 2007 Götz Waschk <waschk@mandriva.org> 1.4.8-1mdv2008.0
+ Revision: 38086
- new version

* Wed May 02 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.6-1mdv2008.0
+ Revision: 20613
- Release 1.4.6
- Remove patch0, no longer needed

* Wed Apr 18 2007 Götz Waschk <waschk@mandriva.org> 1.4.4-1mdv2008.0
+ Revision: 14760
- new version


* Tue Mar 20 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.2-1mdv2007.1
+ Revision: 146893
- Release 1.4.2 (many crash fixes)

* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.4.0-2mdv2007.1
+ Revision: 146600
- bump release
- package smaller NEWS instead of BIG less usefull ChangeLog

* Tue Mar 06 2007 Frederic Crozat <fcrozat@mandriva.com> 1.4.0-1mdv2007.1
+ Revision: 133635
- Release 1.4.0

* Mon Mar 05 2007 Frederic Crozat <fcrozat@mandriva.com> 1.3.16-1mdv2007.1
+ Revision: 133092
-Release 1.3.16
-update patch0 to fix strict aliasing on x86-64 too
-drop additional cflags

* Fri Mar 02 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.3.14-5mdv2007.1
+ Revision: 131588
- bump release
- really fix aliasing bug by compiling with -fno-strict-aliasing
  (patch0 is not enough for x86_64) (#27560)

* Fri Mar 02 2007 Frederic Crozat <fcrozat@mandriva.com> 1.3.14-4mdv2007.1
+ Revision: 131043
- Patch0: fix aliasing (with help from gb) (Mdv bug #27560)

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.3.14-3mdv2007.1
+ Revision: 122248
- rebuild to fix pkgconfig deps

* Sat Feb 17 2007 Götz Waschk <waschk@mandriva.org> 1.3.14-2mdv2007.1
+ Revision: 122123
- rebuild for pkgconfig provides

* Thu Feb 15 2007 Frederic Crozat <fcrozat@mandriva.com> 1.3.14-1mdv2007.1
+ Revision: 121316
- Release 1.3.14

* Fri Feb 09 2007 Frederic Crozat <fcrozat@mandriva.com> 1.3.12-2mdv2007.1
+ Revision: 118385
-Patch0 (GIT): fix crash when RENDER isn't available (fdo bug #9893)

* Mon Jan 22 2007 Frederic Crozat <fcrozat@mandriva.com> 1.3.12-1mdv2007.1
+ Revision: 111991
-Release 1.3.12
-Disable tests, they don't pass upstream right now

* Thu Dec 28 2006 Frederic Crozat <fcrozat@mandriva.com> 1.3.10-1mdv2007.1
+ Revision: 102297
- Release 1.3.10
  Remove patch0, merged upstream
  enable tests at build time, they should pass on iurt now

* Fri Dec 15 2006 Frederic Crozat <fcrozat@mandriva.com> 1.3.8-1mdv2007.1
+ Revision: 97437
- Release 1.3.8
  Patch0: fix symbol check on OPD platform

* Fri Dec 08 2006 Frederic Crozat <fcrozat@mandriva.com> 1.3.6-3mdv2007.1
+ Revision: 93845
- Disable test for now, they don't pass in iurt (seems font related)
- Force rebuild
- Enable back Xvfvb BR
- Release 1.3.6
- Enable tests, they pass now

* Fri Dec 01 2006 Frederic Crozat <fcrozat@mandriva.com> 1.3.4-1mdv2007.1
+ Revision: 89847
- Release 1.3.4
- Add check but disabled for now (doesn't pass all tests)

* Fri Nov 03 2006 Götz Waschk <waschk@mandriva.org> 1.2.6-1mdv2007.1
+ Revision: 76093
- Import cairo

* Fri Nov 03 2006 Götz Waschk <waschk@mandriva.org> 1.2.6-1mdv2007.1
- drop patch
- New version 1.2.6

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 1.2.4-2mdv2007.0
- Patch0 (GIT): various fixes, including Mdv bug #24298

* Tue Aug 22 2006 Frederic Crozat <fcrozat@mandriva.com> 1.2.4-1mdv2007.0
- Release 1.2.4

* Thu Aug 10 2006 Götz Waschk <waschk@mandriva.org> 1.2.2-1mdv2007.0
- drop patches
- New release 1.2.2

* Fri Jul 28 2006 Frederic Crozat <fcrozat@mandriva.com> 1.2.0-3mdv2007.0
- Patch1 (GIT): fix broken text when antialiasing is disabled (Mdv bug #23823)

* Thu Jul 20 2006 Frederic Crozat <fcrozat@mandriva.com> 1.2.0-2mdv2007.0
- Patch0 (GIT): remove Xsync from surface_flush

* Tue Jul 04 2006 Götz Waschk <waschk@mandriva.org> 1.2.0-1mdv2007.0
- New release 1.2.0

* Sat Jun 17 2006 Frederic Crozat <fcrozat@mandriva.com> 1.1.10-1mdv2007.0
- Release 1.1.10

* Thu Jun 15 2006 Frederic Crozat <fcrozat@mandriva.com> 1.1.8-1mdv2007.0
- Release 1.1.8

* Wed Jun 14 2006 Frederic Crozat <fcrozat@mandriva.com> 1.1.7-0.1mdv2007.0
- new snapshot (20060613)
- Remove patch5, no longer needed

* Thu Jun 08 2006 Götz Waschk <waschk@mandriva.org> 1.1.6-2mdv2007.0
- fix buildrequires

* Thu Jun 01 2006 Frederic Crozat <fcrozat@mandriva.com> 1.1.6-1mdv2007.0
- Release 1.1.6
- enable pdf and ps backends (needed for gtk)
- Regenerate patch5

* Sat May 20 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.0.4-3mdk
- add BuildRequires: libxrender-devel libfontconfig-devel

* Wed May 17 2006 Laurent MONTEL <lmontel@mandriva.com> 1.0.4-2
- Rebuild with new xorg

* Wed Mar 15 2006 Götz Waschk <waschk@mandriva.org> 1.0.4-1mdk
- drop patch 4
- source URL
- New release 1.0.4

* Thu Feb 23 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-3mdk
- use mkrel
- Remove patch9, bug is workarounded with gtk+ >= 2.8.12

* Sat Jan 07 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.0.2-2mdk
- Rebuild

* Thu Oct 06 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-1mdk
- Release 1.0.2
- Remove patches 6, 7, 8, 10, 11 (merged upstream)

* Wed Sep 21 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-8mdk 
- Patch10 (CVS): don't use SSE on MMX non SSE CPU
- Patch11 (CVS): fix X error with null pixmaps

* Tue Sep 13 2005 Götz Waschk <waschk@mandriva.org> 1.0.0-7mdk
- add provides to the devel package

* Tue Sep 06 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-6mdk 
- Patch9: disable XRender Composite, unless CAIRO_ENABLE_XRENDER_COMPOSITE 
  environment variable is set to 1

* Tue Aug 30 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-5mdk 
- Patch7 (CVS): better handle agressive inlining and omit-frame-pointer
- Patch8 (CVS): simplify rectangular trapezoids check

* Mon Aug 29 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-4mdk 
- Patch6: fix detection of X with broken render

* Sat Aug 27 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-3mdk
- Patch5: add support for artificial oblique

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-2mdk 
- Explicitly disable all unstable backends (they are already disabled)

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 1.0.0-1mdk 
- Release 1.0.0 (champagne :)
- Remove patches 0, 1, 2, 3 (merged upstream)

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 0.9.2-7mdk 
- Remove test warnings from patch2
- Patch4 : fix subpixel for BGR/vBGR LCD screen

* Tue Aug 23 2005 Frederic Crozat <fcrozat@mandriva.com> 0.9.2-6mdk 
- Add explicit requires on freetype 2.1.10 (needed for embolding)

* Sat Aug 20 2005 Frederic Crozat <fcrozat@mandriva.com> 0.9.2-5mdk 
- Patch3 (CVS): fix null surface crash (seen in qt-gtk engine)
- Patch2 (Sunmoon): add artificial embolding support

* Thu Aug 18 2005 Pascal Terjan <pterjan@mandriva.org> 0.9.2-4mdk
- Patch1 (CVS): fix another crash, this one seen in Evince

* Thu Aug 18 2005 Frederic Crozat <fcrozat@mandriva.com> 0.9.2-3mdk 
- Patch0 (CVS): fix crash in fontconfig font, as seen in Eclipse

* Wed Aug 17 2005 Frederic Crozat <fcrozat@mandriva.com> 0.9.2-2mdk 
- Add conflicts to ease upgrade

* Mon Aug 15 2005 Götz Waschk <waschk@mandriva.org> 0.9.2-1mdk
- New release 0.9.2

* Fri Aug 12 2005 Götz Waschk <waschk@mandriva.org> 0.9.0-1mdk
- major 2
- New release 0.9.0

* Sat Jul 30 2005 Götz Waschk <waschk@mandriva.org> 0.6.0-1mdk
- New release 0.6.0

* Wed Jul 20 2005 Götz Waschk <waschk@mandriva.org> 0.5.2-1mdk
- New release 0.5.2

* Tue Jun 28 2005 Götz Waschk <waschk@mandriva.org> 0.5.1-1mdk
- New release 0.5.1

* Fri May 20 2005 Götz Waschk <waschk@mandriva.org> 0.5.0-1mdk
- enable gtk doc
- New release 0.5.0

* Tue Apr 19 2005 Götz Waschk <waschk@linux-mandrake.com> 0.4.0-1mdk
- add docs
- bump deps
- drop patch
- New release 0.4.0

* Fri Feb 11 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.3.0-2mdk
- add BuildRequires: libpng-devel (for oregano)
- Patch1: glitz 0.4.0 support

* Fri Jan 28 2005 Goetz Waschk <waschk@linux-mandrake.com> 0.3.0-1mdk
- New release 0.3.0

* Wed Nov 24 2004 Jean-Michel Dault <jmdault@revolutionlinux.com> 0.2.0-2mdk
- reenable aclocal, autoheader, autoconf,  automake so that it build
  properly on Mandrake 10.0

* Fri Nov 12 2004 Marcel Pol <mpol@mandrake.org> 0.2.0-1mdk
- 0.2.0
- build against glitz

* Wed Jun 02 2004 Marcel Pol <mpol@mandrake.org> 0.1.23-1mdk
- 0.1.23
- reenable libtoolize

* Thu May 06 2004 Götz Waschk <waschk@linux-mandrake.com> 0.1.22-1mdk
- fix devel provides
- drop redundant buildrequires
- requires new pixman
- autoconf 2.5 macro
- New release 0.1.22

